#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yi-rope
version:              0.11
visibility:           public
id:                   yi-rope-0.11-2TrLoDMWoF76WcfjZRUpIa
key:                  yi-rope-0.11-2TrLoDMWoF76WcfjZRUpIa
license:              GPL-2.0-only
maintainer:           yi-devel@googlegroups.com
author:               AUTHORS
synopsis:             A rope data structure used by Yi
description:          A rope data structure used by Yi
category:             Yi
abi:                  264b5e9e6d573cf87c32690c0ca61a11
exposed:              True
exposed-modules:      Yi.Rope
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yi-rope-0.11
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yi-rope-0.11
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yi-rope-0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yi-rope
hs-libraries:         HSyi-rope-0.11-2TrLoDMWoF76WcfjZRUpIa
depends:
    base-4.18.2.1 binary-0.8.9.1 bytestring-0.11.5.3 deepseq-1.4.8.1
    fingertree-0.1.6.3-5r56lEPailbT3dqi1nhwz text-2.0.2

haddock-interfaces:   /usr/share/doc/haskell-yi-rope/html/yi-rope.haddock
haddock-html:         /usr/share/doc/haskell-yi-rope/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

